from django.db import models
from django.contrib.auth.models import User
from django.core.validators import MinLengthValidator, MaxLengthValidator, RegexValidator

# Create your models here.

class Size(models.Model):
    name = models.TextField(unique=True)

    def __str__(self) -> str:
        return self.name

class Crust(models.Model):
    name = models.TextField(unique=True)

    def __str__(self) -> str:
        return self.name

class Sauce(models.Model):
    name = models.TextField(unique=True)

    def __str__(self) -> str:
        return self.name

class Cheese(models.Model):
    name = models.TextField(unique=True)

    def __str__(self) -> str:
        return self.name

class Topping(models.Model):
    name = models.TextField(unique=True)
    inStock = models.BooleanField(default=True)

    def __str__(self) -> str:
        return self.name

class PizzaOrder(models.Model):
    orderId = models.AutoField(primary_key=True)
    orderedBy = models.ForeignKey(User, on_delete=models.CASCADE)
    # defining foreign keys
    size = models.ForeignKey(Size, on_delete=models.CASCADE, default=1)
    crust = models.ForeignKey(Crust, on_delete=models.CASCADE, default=1)
    sauce = models.ForeignKey(Sauce, on_delete=models.CASCADE, default=1)
    cheese = models.ForeignKey(Cheese, on_delete=models.CASCADE, default=1)
    # interesting relation but works really well for this
    toppings = models.ManyToManyField(Topping)

    paymentComplete = models.BooleanField(default=False)

    created_at = models.DateTimeField(auto_now_add=True)

class DeliveryDetails(models.Model):
    order = models.OneToOneField(PizzaOrder, on_delete=models.CASCADE, related_name="delivery")
    
    # use validators to ensure non-empty fields
    name = models.CharField(max_length=50, validators=[MinLengthValidator(2)])
    address = models.TextField(validators=[MinLengthValidator(2)])
    cardNumber = models.CharField(max_length=16, validators=[MinLengthValidator(16), MaxLengthValidator(16)])
    cardExpiry = models.DateField()
    cardCvv = models.CharField(max_length=3, validators=[MinLengthValidator(3)])

    paid_at = models.DateTimeField(auto_now_add=True)